import setuptools

setuptools.setup(
    name="zq-tools",
    version="0.2.0",
    author="zzqq2199",
    author_email="zhouquanjs@qq.com",
    description="A collection of tools for zzqq2199",
    packages=["zq_tools"]
)